class Options

  require 'getoptlong'

  # the name of the output directory
  attr_accessor :op_dir
  
  # include private and protected methods in the
  # output
  attr_accessor :show_all
  
  # name of the file, class or module to display in
  # the initial index page (if not specified
  # the first file we encounter is used)
  attr_accessor :main_page

  OPTION_LIST = [
    [ "--all",     "-a", GetoptLong::NO_ARGUMENT ],
    [ "--debug",   "-d", GetoptLong::NO_ARGUMENT ],
    [ "--main",    "-m", GetoptLong::REQUIRED_ARGUMENT ],
    [ "--op",      "-o", GetoptLong::REQUIRED_ARGUMENT ],
    [ "--version", "-v", GetoptLong::NO_ARGUMENT ],

  ]

  # Show usage and exit
  
  def usage(msg = nil)

    $stderr.puts(msg) if msg

    name = File.basename($0)
    $stderr.puts "
usage:

  #{name} [options]  [names...]

options:

  --all        include all methods (not just public) in the output
  --main name  make 'name' the page displayed in the index page
  --op dir     set the output directory
  --version    display  RDoc's version

"
    exit 1
  end

  # Parse command line options

  def initialize
    @op_dir = "doc"
    @show_all = false
    @main_page = nil

    go = GetoptLong.new(*OPTION_LIST)
    go.quiet = true
    go.each do |opt, arg|
      case opt
      when "--debug"
        $DEBUG = true
      when "--op"
	@op_dir = arg
      when "--all"
	@show_all = true
      when "--main"
	@main_page = arg
      when "--version"
	$stderr.puts VERSION_STRING
	exit
      end
    end
  rescue GetoptLong::InvalidOption => error
    usage(error.message)
  end
end
